#!/bin/bash

cd `dirname $0`

BINARY=espruino_1v66_espruino_1r3.bin
PORT=$1

bold=`tput bold`
normal=`tput sgr0`
boldred=${bold}$(tput setaf 1)
boldgreen=${bold}$(tput setaf 2)


function error() {
  echo "${boldred}----------------------------------------------------"
  echo "    $@"
  echo "----------------------------------------------------${normal}"
}
function goodnews() {
  echo "${boldgreen}----------------------------------------------------"
  echo "    $@"
  echo "----------------------------------------------------${normal}"
}

while true; do
  echo "${bold}------------------------ $PORT -"
  echo "  Plug a board USB while holding BTN1"
  echo "---------------------------------------${normal}"
  
  # wait for the port to appear
  while [ ! -e "$PORT" ]; do
    sleep 0.5s
  done

  # Checking for prompt
  python checkprompt.py $PORT
  if [ $? -eq 0 ]; then
    echo "Prompt found - Espruino booted"

    # do the test!
    python sendfile.py $PORT selftest.js 

    # Test written
    echo "Please wait for the BLUE LED to turn off"
    echo "${boldgreen}GREEN${normal} means PASS"
    echo "${boldred}RED${normal} means FAILURE"
  else
    echo "No prompt. Assuming bootloader"
       
    # flash.../
    python stm32loader.py -ewvX -p $PORT -a 0x08002800 -s 10240 ${BINARY}
    if [ $? -eq 0 ]; then
      goodnews "FLASHING SUCEEDED"
      echo "Please wait... testing..."
    else
      error "FLASHING FAILED"
    fi

    echo "Please remove the board"
  fi

  # Wait until the board is removed  
  while [ -e "$PORT" ]; do
    sleep 0.1s
  done

  echo
  echo
  echo
  echo
  echo
  
done


